@@ -22,6 +22,7 @@ NetworkDisconnectionWidget::~NetworkDisconnectionWidget()
 
 void NetworkDisconnectionWidget::initUI()
 {
+    DLOG << "NetworkDisconnectionWidget initUI";
     setStyleSheet(".NetworkDisconnectionWidget{background-color: white; border-radius: 10px;}");
 
     QVBoxLayout *mainLayout = new QVBoxLayout();
@@ -62,6 +63,7 @@ void NetworkDisconnectionWidget::initUI()
     mainLayout->addLayout(buttonLayout);
     mainLayout->addSpacing(10);
     mainLayout->addLayout(indexLayout);
+    DLOG << "NetworkDisconnectionWidget initUI finished";
 }
 
 void NetworkDisconnectionWidget::backPage()
@@ -81,8 +83,10 @@ void NetworkDisconnectionWidget::themeChanged(int theme)
     DLOG << "Theme changed to:" << (theme == 1 ? "light" : "dark");
     //light
     if (theme == 1) {
+        DLOG << "Theme is light, setting stylesheet";
         setStyleSheet(".NetworkDisconnectionWidget{background-color: white; border-radius: 10px;}");
     } else {
+        DLOG << "Theme is dark, setting stylesheet";
         setStyleSheet(".NetworkDisconnectionWidget{background-color: rgb(37, 37, 37); border-radius: 10px;}");
         //dark
     }
