@@ -1,4 +1,5 @@
 ﻿#include "optionsmanager.h"
+#include "common/log.h"
 
 OptionsManager::OptionsManager() : QObject() { }
 
@@ -6,6 +7,7 @@ OptionsManager::~OptionsManager() { }
 
 OptionsManager *OptionsManager::instance()
 {
+    DLOG << "Accessing OptionsManager singleton instance";
     static OptionsManager ins;
     return &ins;
 }
@@ -17,26 +19,34 @@ QMap<QString, QStringList> OptionsManager::getUserOptions() const
 
 QStringList OptionsManager::getUserOption(const QString &option) const
 {
-    if (userOptions.contains(option))
+    DLOG << "Getting user option:" << option.toStdString();
+    if (userOptions.contains(option)) {
+        DLOG << "Found option with" << userOptions[option].size() << "values";
         return userOptions[option];
-    else
+    } else {
+        WLOG << "Option not found:" << option.toStdString();
         return QStringList();
+    }
 }
 
 void OptionsManager::setUserOptions(const QMap<QString, QStringList> &value)
 {
+    DLOG << "Setting all user options, count:" << value.size();
     userOptions = value;
 }
 
 void OptionsManager::addUserOption(const QString &option, const QStringList &value)
 {
-    // update user options
-    if (userOptions.contains(option))
+    DLOG << "Adding/updating option:" << option.toStdString() << "with" << value.size() << "values";
+    if (userOptions.contains(option)) {
+        DLOG << "Replacing existing option:" << option.toStdString();
         userOptions.remove(option);
+    }
     userOptions[option] = value;
 }
 
 void OptionsManager::clear()
 {
+    DLOG << "Clearing all user options";
     userOptions.clear();
 }
