@@ -5,6 +5,7 @@
 #include <QFile>
 #include <QFlags>
 #include <QHash>
+#include <QDebug>
 
 #include "quazip.h"
 
@@ -57,6 +58,7 @@ class QuaZipPrivate {
     bool autoClose;
     inline QTextCodec *getDefaultFileNameCodec()
     {
+        qInfo() << "Getting default file name codec";
         if (defaultFileNameCodec == NULL) {
             return QTextCodec::codecForLocale();
         } else {
@@ -76,6 +78,7 @@ class QuaZipPrivate {
       zip64(false),
       autoClose(true)
     {
+        qInfo() << "Constructing QuaZipPrivate with QuaZip*";
         unzFile_f = NULL;
         zipFile_f = NULL;
         lastMappedDirectoryEntry.num_of_file = 0;
@@ -95,6 +98,7 @@ class QuaZipPrivate {
       zip64(false),
       autoClose(true)
     {
+        qInfo() << "Constructing QuaZipPrivate with QuaZip* and zipName:" << zipName;
         unzFile_f = NULL;
         zipFile_f = NULL;
         lastMappedDirectoryEntry.num_of_file = 0;
@@ -113,6 +117,7 @@ class QuaZipPrivate {
       zip64(false),
       autoClose(true)
     {
+        qInfo() << "Constructing QuaZipPrivate with QuaZip* and ioDevice";
         unzFile_f = NULL;
         zipFile_f = NULL;
         lastMappedDirectoryEntry.num_of_file = 0;
@@ -136,6 +141,7 @@ QTextCodec *QuaZipPrivate::defaultFileNameCodec = NULL;
 
 void QuaZipPrivate::clearDirectoryMap()
 {
+    qInfo() << "Clearing directory map";
     directoryCaseInsensitive.clear();
     directoryCaseSensitive.clear();
     lastMappedDirectoryEntry.num_of_file = 0;
@@ -144,7 +150,9 @@ void QuaZipPrivate::clearDirectoryMap()
 
 void QuaZipPrivate::addCurrentFileToDirectoryMap(const QString &fileName)
 {
+    qInfo() << "Adding current file to directory map, fileName:" << fileName;
     if (!hasCurrentFile_f || fileName.isEmpty()) {
+        qInfo() << "No current file or empty filename";
         return;
     }
     // Adds current file to filename map as fileName
@@ -154,31 +162,41 @@ void QuaZipPrivate::addCurrentFileToDirectoryMap(const QString &fileName)
     // Only add lowercase to directory map if not already there
     // ensures only map the first one seen
     QString lower = fileName.toLower();
-    if (!directoryCaseInsensitive.contains(lower))
+    if (!directoryCaseInsensitive.contains(lower)) {
+        qInfo() << "Adding to case-insensitive map";
         directoryCaseInsensitive.insert(lower, fileDirectoryPos);
+    }
     // Mark last one
-    if (fileDirectoryPos.pos_in_zip_directory > lastMappedDirectoryEntry.pos_in_zip_directory)
+    if (fileDirectoryPos.pos_in_zip_directory > lastMappedDirectoryEntry.pos_in_zip_directory) {
+        qInfo() << "Updating last mapped directory entry";
         lastMappedDirectoryEntry = fileDirectoryPos;
+    }
 }
 
 bool QuaZipPrivate::goToFirstUnmappedFile()
 {
+    qInfo() << "Going to first unmapped file";
     zipError = UNZ_OK;
     if (mode != QuaZip::mdUnzip) {
         qWarning("QuaZipPrivate::goToNextUnmappedFile(): ZIP is not open in mdUnzip mode");
+        qInfo() << "Not in mdUnzip mode";
         return false;
     }
     // If not mapped anything, go to beginning
     if (lastMappedDirectoryEntry.pos_in_zip_directory == 0) {
+        qInfo() << "Going to first file";
         unzGoToFirstFile(unzFile_f);
     } else {
         // Goto the last one mapped, plus one
+        qInfo() << "Going to next unmapped file";
         unzGoToFilePos64(unzFile_f, &lastMappedDirectoryEntry);
         unzGoToNextFile(unzFile_f);
     }
     hasCurrentFile_f=zipError==UNZ_OK;
-    if(zipError==UNZ_END_OF_LIST_OF_FILE)
+    if(zipError==UNZ_END_OF_LIST_OF_FILE) {
+      qInfo() << "End of file list";
       zipError=UNZ_OK;
+    }
     return hasCurrentFile_f;
 }
 
@@ -189,6 +207,7 @@ bool QuaZipPrivate::goToFirstUnmappedFile()
 QuaZip::QuaZip():
   p(new QuaZipPrivate(this))
 {
+    qInfo() << "Constructing QuaZip (default)";
 }
 
 /**
@@ -198,6 +217,7 @@ QuaZip::QuaZip():
 QuaZip::QuaZip(const QString& zipName):
   p(new QuaZipPrivate(this, zipName))
 {
+    qInfo() << "Constructing QuaZip with zipName:" << zipName;
 }
 
 /**
@@ -207,10 +227,12 @@ QuaZip::QuaZip(const QString& zipName):
 QuaZip::QuaZip(QIODevice *ioDevice):
   p(new QuaZipPrivate(this, ioDevice))
 {
+    qInfo() << "Constructing QuaZip with ioDevice";
 }
 
 QuaZip::~QuaZip()
 {
+  qInfo() << "Destructing QuaZip";
   if(isOpen())
     close();
   delete p;
@@ -218,6 +240,7 @@ QuaZip::~QuaZip()
 
 bool QuaZip::open(Mode mode, zlib_filefunc_def* ioApi)
 {
+  qInfo() << "Opening zip file" << p->zipName << "in mode" << mode;
   p->zipError=UNZ_OK;
   if(isOpen()) {
     qWarning("QuaZip::open(): ZIP already opened");
@@ -227,20 +250,24 @@ bool QuaZip::open(Mode mode, zlib_filefunc_def* ioApi)
   if (ioDevice == NULL) {
     if (p->zipName.isEmpty()) {
       qWarning("QuaZip::open(): set either ZIP file name or IO device first");
+      qInfo() << "No zip name or IO device set";
       return false;
     } else {
+      qInfo() << "Creating new QFile for" << p->zipName;
       ioDevice = new QFile(p->zipName);
     }
   }
   unsigned flags = 0;
   switch(mode) {
     case mdUnzip:
+      qInfo() << "Opening in mdUnzip mode";
       if (ioApi == NULL) {
           if (p->autoClose)
               flags |= UNZ_AUTO_CLOSE;
           p->unzFile_f=unzOpenInternal(ioDevice, NULL, 1, flags);
       } else {
           // QuaZIP pre-zip64 compatibility mode
+          qInfo() << "Using custom ioApi";
           p->unzFile_f=unzOpen2(ioDevice, ioApi);
           if (p->unzFile_f != NULL) {
               if (p->autoClose) {
@@ -258,6 +285,7 @@ bool QuaZip::open(Mode mode, zlib_filefunc_def* ioApi)
             qWarning("QuaZip::open(): "
                      "only mdCreate can be used with "
                      "sequential devices");
+            qInfo() << "Sequential device with mdUnzip";
             return false;
         }
         p->mode=mode;
@@ -267,11 +295,13 @@ bool QuaZip::open(Mode mode, zlib_filefunc_def* ioApi)
         p->zipError=UNZ_OPENERROR;
         if (!p->zipName.isEmpty())
           delete ioDevice;
+        qInfo() << "unzOpen failed";
         return false;
       }
     case mdCreate:
     case mdAppend:
     case mdAdd:
+      qInfo() << "Opening in create/append/add mode";
       if (ioApi == NULL) {
           if (p->autoClose)
               flags |= ZIP_AUTO_CLOSE;
@@ -284,6 +314,7 @@ bool QuaZip::open(Mode mode, zlib_filefunc_def* ioApi)
               NULL, NULL, flags);
       } else {
           // QuaZIP pre-zip64 compatibility mode
+          qInfo() << "Using custom ioApi";
           p->zipFile_f=zipOpen2(ioDevice,
               mode==mdCreate?APPEND_STATUS_CREATE:
               mode==mdAppend?APPEND_STATUS_CREATEAFTER:
@@ -303,6 +334,7 @@ bool QuaZip::open(Mode mode, zlib_filefunc_def* ioApi)
                          "sequential devices");
                 if (!p->zipName.isEmpty())
                     delete ioDevice;
+                qInfo() << "Sequential device with non-create mode";
                 return false;
             }
             zipSetFlags(p->zipFile_f, ZIP_SEQUENTIAL);
@@ -314,12 +346,14 @@ bool QuaZip::open(Mode mode, zlib_filefunc_def* ioApi)
         p->zipError=UNZ_OPENERROR;
         if (!p->zipName.isEmpty())
           delete ioDevice;
+        qInfo() << "zipOpen failed";
         return false;
       }
     default:
       qWarning("QuaZip::open(): unknown mode: %d", (int)mode);
       if (!p->zipName.isEmpty())
         delete ioDevice;
+      qInfo() << "Unknown mode";
       return false;
       break;
   }
@@ -327,17 +361,20 @@ bool QuaZip::open(Mode mode, zlib_filefunc_def* ioApi)
 
 void QuaZip::close()
 {
+  qInfo() << "Closing zip file" << p->zipName;
   p->zipError=UNZ_OK;
   switch(p->mode) {
     case mdNotOpen:
       qWarning("QuaZip::close(): ZIP is not open");
       return;
     case mdUnzip:
+      qInfo() << "Closing in mdUnzip mode";
       p->zipError=unzClose(p->unzFile_f);
       break;
     case mdCreate:
     case mdAppend:
     case mdAdd:
+      qInfo() << "Closing in create/append/add mode";
       p->zipError=zipClose(p->zipFile_f, 
           p->comment.isNull() ? NULL
           : p->commentCodec->fromUnicode(p->comment).constData());
@@ -348,6 +385,7 @@ void QuaZip::close()
   }
   // opened by name, need to delete the internal IO device
   if (!p->zipName.isEmpty()) {
+      qInfo() << "Deleting internal IO device";
       delete p->ioDevice;
       p->ioDevice = NULL;
   }
@@ -358,8 +396,10 @@ void QuaZip::close()
 
 void QuaZip::setZipName(const QString& zipName)
 {
+  qInfo() << "Setting zip name to:" << zipName;
   if(isOpen()) {
     qWarning("QuaZip::setZipName(): ZIP is already open!");
+    qInfo() << "ZIP already open";
     return;
   }
   p->zipName=zipName;
@@ -368,6 +408,7 @@ void QuaZip::setZipName(const QString& zipName)
 
 void QuaZip::setIoDevice(QIODevice *ioDevice)
 {
+  qInfo() << "Setting IO device";
   if(isOpen()) {
     qWarning("QuaZip::setIoDevice(): ZIP is already open!");
     return;
@@ -378,6 +419,7 @@ void QuaZip::setIoDevice(QIODevice *ioDevice)
 
 int QuaZip::getEntriesCount()const
 {
+  qInfo() << "Getting entries count";
   QuaZip *fakeThis=(QuaZip*)this; // non-const
   fakeThis->p->zipError=UNZ_OK;
   if(p->mode!=mdUnzip) {
@@ -385,13 +427,16 @@ int QuaZip::getEntriesCount()const
     return -1;
   }
   unz_global_info64 globalInfo;
-  if((fakeThis->p->zipError=unzGetGlobalInfo64(p->unzFile_f, &globalInfo))!=UNZ_OK)
+  if((fakeThis->p->zipError=unzGetGlobalInfo64(p->unzFile_f, &globalInfo))!=UNZ_OK) {
+    qInfo() << "unzGetGlobalInfo64 error:" << p->zipError;
     return p->zipError;
+  }
   return (int)globalInfo.number_entry;
 }
 
 QString QuaZip::getComment()const
 {
+  qInfo() << "Getting zip comment";
   QuaZip *fakeThis=(QuaZip*)this; // non-const
   fakeThis->p->zipError=UNZ_OK;
   if(p->mode!=mdUnzip) {
@@ -400,33 +445,41 @@ QString QuaZip::getComment()const
   }
   unz_global_info64 globalInfo;
   QByteArray comment;
-  if((fakeThis->p->zipError=unzGetGlobalInfo64(p->unzFile_f, &globalInfo))!=UNZ_OK)
+  if((fakeThis->p->zipError=unzGetGlobalInfo64(p->unzFile_f, &globalInfo))!=UNZ_OK) {
+    qInfo() << "unzGetGlobalInfo64 error:" << p->zipError;
     return QString();
+  }
   comment.resize(globalInfo.size_comment);
-  if((fakeThis->p->zipError=unzGetGlobalComment(p->unzFile_f, comment.data(), comment.size())) < 0)
+  if((fakeThis->p->zipError=unzGetGlobalComment(p->unzFile_f, comment.data(), comment.size())) < 0) {
+    qInfo() << "unzGetGlobalComment error:" << p->zipError;
     return QString();
+  }
   fakeThis->p->zipError = UNZ_OK;
   return p->commentCodec->toUnicode(comment);
 }
 
 bool QuaZip::setCurrentFile(const QString& fileName, CaseSensitivity cs)
 {
+  qInfo() << "Setting current file to:" << fileName << "case sensitivity:" << cs;
   p->zipError=UNZ_OK;
   if(p->mode!=mdUnzip) {
     qWarning("QuaZip::setCurrentFile(): ZIP is not open in mdUnzip mode");
     return false;
   }
   if(fileName.isEmpty()) {
+    qInfo() << "Empty filename";
     p->hasCurrentFile_f=false;
     return true;
   }
   // Unicode-aware reimplementation of the unzLocateFile function
   if(p->unzFile_f==NULL) {
     p->zipError=UNZ_PARAMERROR;
+    qInfo() << "unzFile_f is NULL";
     return false;
   }
   if(fileName.length()>MAX_FILE_NAME_LENGTH) {
     p->zipError=UNZ_PARAMERROR;
+    qInfo() << "Filename too long";
     return false;
   }
   // Find the file by name
@@ -439,11 +492,15 @@ bool QuaZip::setCurrentFile(const QString& fileName, CaseSensitivity cs)
   unz64_file_pos fileDirPos;
   fileDirPos.pos_in_zip_directory = 0;
   if (sens) {
-      if (p->directoryCaseSensitive.contains(fileName))
+      if (p->directoryCaseSensitive.contains(fileName)) {
+          qInfo() << "Found in case-sensitive map";
           fileDirPos = p->directoryCaseSensitive.value(fileName);
+      }
   } else {
-      if (p->directoryCaseInsensitive.contains(lower))
+      if (p->directoryCaseInsensitive.contains(lower)) {
+          qInfo() << "Found in case-insensitive map";
           fileDirPos = p->directoryCaseInsensitive.value(lower);
+      }
   }
 
   if (fileDirPos.pos_in_zip_directory != 0) {
@@ -455,9 +512,13 @@ bool QuaZip::setCurrentFile(const QString& fileName, CaseSensitivity cs)
       return p->hasCurrentFile_f;
 
   // Not mapped yet, start from where we have got to so far
+  qInfo() << "Not in map, searching from first unmapped file";
   for(bool more=p->goToFirstUnmappedFile(); more; more=goToNextFile()) {
     current=getCurrentFileName();
-    if(current.isEmpty()) return false;
+    if(current.isEmpty()) {
+        qInfo() << "getCurrentFileName returned empty string";
+        return false;
+    }
     if(sens) {
       if(current==fileName) break;
     } else {
@@ -469,6 +530,7 @@ bool QuaZip::setCurrentFile(const QString& fileName, CaseSensitivity cs)
 
 bool QuaZip::goToFirstFile()
 {
+  qInfo() << "Going to first file";
   p->zipError=UNZ_OK;
   if(p->mode!=mdUnzip) {
     qWarning("QuaZip::goToFirstFile(): ZIP is not open in mdUnzip mode");
@@ -481,6 +543,7 @@ bool QuaZip::goToFirstFile()
 
 bool QuaZip::goToNextFile()
 {
+  qInfo() << "Going to next file";
   p->zipError=UNZ_OK;
   if(p->mode!=mdUnzip) {
     qWarning("QuaZip::goToFirstFile(): ZIP is not open in mdUnzip mode");
@@ -488,31 +551,37 @@ bool QuaZip::goToNextFile()
   }
   p->zipError=unzGoToNextFile(p->unzFile_f);
   p->hasCurrentFile_f=p->zipError==UNZ_OK;
-  if(p->zipError==UNZ_END_OF_LIST_OF_FILE)
+  if(p->zipError==UNZ_END_OF_LIST_OF_FILE) {
+    qInfo() << "End of file list";
     p->zipError=UNZ_OK;
   return p->hasCurrentFile_f;
 }
 
 bool QuaZip::getCurrentFileInfo(QuaZipFileInfo *info)const
 {
+    qInfo() << "Getting current file info (32-bit)";
     QuaZipFileInfo64 info64;
     if (info == NULL) { // Very unlikely because of the overloads
+        qInfo() << "info is NULL";
         return false;
     }
     if (getCurrentFileInfo(&info64)) {
         info64.toQuaZipFileInfo(*info);
         return true;
     } else {
+        qInfo() << "getCurrentFileInfo(&info64) failed";
         return false;
     }
 }
 
 bool QuaZip::getCurrentFileInfo(QuaZipFileInfo64 *info)const
 {
+  qInfo() << "Getting current file info (64-bit)";
   QuaZip *fakeThis=(QuaZip*)this; // non-const
   fakeThis->p->zipError=UNZ_OK;
   if(p->mode!=mdUnzip) {
     qWarning("QuaZip::getCurrentFileInfo(): ZIP is not open in mdUnzip mode");
+    qInfo() << "Not in mdUnzip mode";
     return false;
   }
   unz_file_info64 info_z;
@@ -554,20 +623,29 @@ bool QuaZip::getCurrentFileInfo(QuaZipFileInfo64 *info)const
 
 QString QuaZip::getCurrentFileName()const
 {
+  qInfo() << "Getting current file name";
   QuaZip *fakeThis=(QuaZip*)this; // non-const
   fakeThis->p->zipError=UNZ_OK;
   if(p->mode!=mdUnzip) {
     qWarning("QuaZip::getCurrentFileName(): ZIP is not open in mdUnzip mode");
+    qInfo() << "Not in mdUnzip mode";
     return QString();
   }
-  if(!isOpen()||!hasCurrentFile()) return QString();
+  if(!isOpen()||!hasCurrentFile()) {
+      qInfo() << "Not open or no current file";
+      return QString();
+  }
   QByteArray fileName(MAX_FILE_NAME_LENGTH, 0);
   if((fakeThis->p->zipError=unzGetCurrentFileInfo64(p->unzFile_f, NULL, fileName.data(), fileName.size(),
-      NULL, 0, NULL, 0))!=UNZ_OK)
+      NULL, 0, NULL, 0))!=UNZ_OK) {
+    qInfo() << "unzGetCurrentFileInfo64 error:" << p->zipError;
     return QString();
+  }
   QString result = p->fileNameCodec->toUnicode(fileName.constData());
-  if (result.isEmpty())
+  if (result.isEmpty()) {
+      qInfo() << "Empty filename";
       return result;
+  }
   // Add to directory map
   p->addCurrentFileToDirectoryMap(result);
   return result;
@@ -576,11 +654,13 @@ QString QuaZip::getCurrentFileName()const
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 void QuaZip::setFileNameCodec(QTextCodec *fileNameCodec)
 {
+  qInfo() << "Setting file name codec by pointer";
   p->fileNameCodec=fileNameCodec;
 }
 
 void QuaZip::setFileNameCodec(const char *fileNameCodecName)
 {
+  qInfo() << "Setting file name codec by name:" << fileNameCodecName;
   p->fileNameCodec=QTextCodec::codecForName(fileNameCodecName);
 }
 
@@ -591,47 +671,56 @@ QTextCodec *QuaZip::getFileNameCodec()const
 
 void QuaZip::setCommentCodec(QTextCodec *commentCodec)
 {
+  qInfo() << "Setting comment codec by pointer";
   p->commentCodec=commentCodec;
 }
 
 void QuaZip::setCommentCodec(const char *commentCodecName)
 {
+  qInfo() << "Setting comment codec by name:" << commentCodecName;
   p->commentCodec=QTextCodec::codecForName(commentCodecName);
 }
 
 QTextCodec *QuaZip::getCommentCodec()const
 {
+  qInfo() << "Getting comment codec";
   return p->commentCodec;
 }
 #else
 void QuaZip::setFileNameEncoding(QStringConverter::Encoding encoding)
 {
+    qInfo() << "Setting file name encoding to:" << encoding;
     p->fileNameEncoding = encoding;
 }
 
 QStringConverter::Encoding QuaZip::getFileNameEncoding() const
 {
+    qInfo() << "Getting file name encoding";
     return p->fileNameEncoding;
 }
 
 void QuaZip::setCommentEncoding(QStringConverter::Encoding encoding)
 {
+    qInfo() << "Setting comment encoding to:" << encoding;
     p->commentEncoding = encoding;
 }
 
 QStringConverter::Encoding QuaZip::getCommentEncoding() const
 {
+    qInfo() << "Getting comment encoding";
     return p->commentEncoding;
 }
 #endif
 
 QString QuaZip::getZipName() const
 {
+  qInfo() << "Getting zip name";
   return p->zipName;
 }
 
 QIODevice *QuaZip::getIoDevice() const
 {
+  qInfo() << "Getting IO device";
   if (!p->zipName.isEmpty()) // opened by name, using an internal QIODevice
     return NULL;
   return p->ioDevice;
@@ -639,46 +728,55 @@ QIODevice *QuaZip::getIoDevice() const
 
 QuaZip::Mode QuaZip::getMode()const
 {
+  qInfo() << "Getting mode";
   return p->mode;
 }
 
 bool QuaZip::isOpen()const
 {
+  qInfo() << "Checking if open";
   return p->mode!=mdNotOpen;
 }
 
 int QuaZip::getZipError() const
 {
+  qInfo() << "Getting zip error";
   return p->zipError;
 }
 
 void QuaZip::setComment(const QString& comment)
 {
+  qInfo() << "Setting comment:" << comment;
   p->comment=comment;
 }
 
 bool QuaZip::hasCurrentFile()const
 {
+  qInfo() << "Checking for current file";
   return p->hasCurrentFile_f;
 }
 
 unzFile QuaZip::getUnzFile()
 {
+  qInfo() << "Getting unzFile handle";
   return p->unzFile_f;
 }
 
 zipFile QuaZip::getZipFile()
 {
+  qInfo() << "Getting zipFile handle";
   return p->zipFile_f;
 }
 
 void QuaZip::setDataDescriptorWritingEnabled(bool enabled)
 {
+    qInfo() << "Setting data descriptor writing enabled to:" << enabled;
     p->dataDescriptorWritingEnabled = enabled;
 }
 
 bool QuaZip::isDataDescriptorWritingEnabled() const
 {
+    qInfo() << "Checking if data descriptor writing is enabled";
     return p->dataDescriptorWritingEnabled;
 }
 
@@ -688,6 +786,7 @@ TFileInfo QuaZip_getFileInfo(QuaZip *zip, bool *ok);
 template<>
 QuaZipFileInfo QuaZip_getFileInfo(QuaZip *zip, bool *ok)
 {
+    qInfo() << "Template helper: Getting QuaZipFileInfo";
     QuaZipFileInfo info;
     *ok = zip->getCurrentFileInfo(&info);
     return info;
@@ -696,6 +795,7 @@ QuaZipFileInfo QuaZip_getFileInfo(QuaZip *zip, bool *ok)
 template<>
 QuaZipFileInfo64 QuaZip_getFileInfo(QuaZip *zip, bool *ok)
 {
+    qInfo() << "Template helper: Getting QuaZipFileInfo64";
     QuaZipFileInfo64 info;
     *ok = zip->getCurrentFileInfo(&info);
     return info;
@@ -704,6 +804,7 @@ QuaZipFileInfo64 QuaZip_getFileInfo(QuaZip *zip, bool *ok)
 template<>
 QString QuaZip_getFileInfo(QuaZip *zip, bool *ok)
 {
+    qInfo() << "Template helper: Getting file name as QString";
     QString name = zip->getCurrentFileName();
     *ok = !name.isEmpty();
     return name;
@@ -712,6 +813,7 @@ QString QuaZip_getFileInfo(QuaZip *zip, bool *ok)
 template<typename TFileInfo>
 bool QuaZipPrivate::getFileInfoList(QList<TFileInfo> *result) const
 {
+  qInfo() << "Getting file info list";
   QuaZipPrivate *fakeThis=const_cast<QuaZipPrivate*>(this);
   fakeThis->zipError=UNZ_OK;
   if (mode!=QuaZip::mdUnzip) {
@@ -727,51 +829,69 @@ bool QuaZipPrivate::getFileInfoList(QList<TFileInfo> *result) const
       do {
           bool ok;
           result->append(QuaZip_getFileInfo<TFileInfo>(q, &ok));
-          if (!ok)
+          if (!ok) {
+              qInfo() << "QuaZip_getFileInfo failed";
               return false;
+          }
       } while (q->goToNextFile());
   }
-  if (zipError != UNZ_OK)
+  if (zipError != UNZ_OK) {
+      qInfo() << "zipError is not UNZ_OK:" << zipError;
       return false;
+  }
   if (currentFile.isEmpty()) {
-      if (!q->goToFirstFile())
+      if (!q->goToFirstFile()) {
+          qInfo() << "goToFirstFile failed";
           return false;
+      }
   } else {
-      if (!q->setCurrentFile(currentFile))
+      if (!q->setCurrentFile(currentFile)) {
+          qInfo() << "setCurrentFile failed";
           return false;
+      }
   }
   return true;
 }
 
 QStringList QuaZip::getFileNameList() const
 {
+    qInfo() << "Getting file name list";
     QStringList list;
     if (p->getFileInfoList(&list))
         return list;
-    else
+    else {
+        qInfo() << "getFileInfoList failed";
         return QStringList();
+    }
 }
 
 QList<QuaZipFileInfo> QuaZip::getFileInfoList() const
 {
+    qInfo() << "Getting file info list (32-bit)";
     QList<QuaZipFileInfo> list;
     if (p->getFileInfoList(&list))
         return list;
-    else
+    else {
+        qInfo() << "getFileInfoList failed";
         return QList<QuaZipFileInfo>();
+    }
 }
 
 QList<QuaZipFileInfo64> QuaZip::getFileInfoList64() const
 {
+    qInfo() << "Getting file info list (64-bit)";
     QList<QuaZipFileInfo64> list;
     if (p->getFileInfoList(&list))
         return list;
-    else
+    else {
+        qInfo() << "getFileInfoList failed";
         return QList<QuaZipFileInfo64>();
+    }
 }
 
 Qt::CaseSensitivity QuaZip::convertCaseSensitivity(QuaZip::CaseSensitivity cs)
 {
+  qInfo() << "Converting case sensitivity enum";
   if (cs == csDefault) {
 #ifdef Q_OS_WIN
       return Qt::CaseInsensitive;
@@ -785,30 +905,36 @@ Qt::CaseSensitivity QuaZip::convertCaseSensitivity(QuaZip::CaseSensitivity cs)
 
 void QuaZip::setDefaultFileNameCodec(QTextCodec *codec)
 {
+    qInfo() << "Setting default file name codec by pointer";
     QuaZipPrivate::defaultFileNameCodec = codec;
 }
 
 void QuaZip::setDefaultFileNameCodec(const char *codecName)
 {
+    qInfo() << "Setting default file name codec by name:" << codecName;
     setDefaultFileNameCodec(QTextCodec::codecForName(codecName));
 }
 
 void QuaZip::setZip64Enabled(bool zip64)
 {
+    qInfo() << "Setting zip64 enabled to:" << zip64;
     p->zip64 = zip64;
 }
 
 bool QuaZip::isZip64Enabled() const
 {
+    qInfo() << "Checking if zip64 is enabled";
     return p->zip64;
 }
 
 bool QuaZip::isAutoClose() const
 {
+    qInfo() << "Checking if auto-close is enabled";
     return p->autoClose;
 }
 
 void QuaZip::setAutoClose(bool autoClose) const
 {
+    qInfo() << "Setting auto-close to:" << autoClose;
     p->autoClose = autoClose;
 }
