@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ta">
 <context>
     <name>Application</name>
     <message>
@@ -32,6 +30,7 @@
     <name>cooperation_core::BottomLabel</name>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="341"/>
+        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="373"/>
         <source>Local IP: %1</source>
         <translation>மின் ஐபிப்பெட்டி: %1</translation>
     </message>
@@ -40,8 +39,8 @@
     <name>cooperation_core::ConfirmWidget</name>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="25"/>
-        <source>"%1" send some files to you</source>
-        <translation>"%1" உங்களுக்கு சில கோப்புகளை அனுப்புகிறது</translation>
+        <source>&quot;%1&quot; send some files to you</source>
+        <translation>&quot;%1&quot; உங்களுக்கு சில கோப்புகளை அனுப்புகிறது</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="34"/>
@@ -68,6 +67,7 @@
     <name>cooperation_core::CooperationTaskDialog</name>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="111"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="131"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>நிறுத்து</translation>
@@ -129,7 +129,7 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
-        <source>When a connection is made between two devices, the initiator's keyboard and mouse can be used to control the other device</source>
+        <source>When a connection is made between two devices, the initiator&apos;s keyboard and mouse can be used to control the other device</source>
         <translation>இரண்டு பொருட்களுக்கு இடையில் தொடர்பு கொள்ளும்போது, தொடர்பு ஏற்படுத்துவோரின் கீ-பேட்டில் மற்றும் மௌசை மற்றொரு பொருட்களை நியமிக்க பயன்படுத்தலாம்</translation>
     </message>
     <message>
@@ -195,6 +195,7 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="248"/>
+        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="257"/>
         <source>Please click to confirm to enable the LAN discovery service!</source>
         <translation>மையக பிரிவு தேடல் சேவையை செயல்படுத்த உறுதியளிக்க கீழே கிளிக் செய்யவும்!</translation>
     </message>
@@ -205,8 +206,8 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="258"/>
-        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned onRight click on Windows Start menu ->Computer Management ->Services and Applications ->Services to enable Bonjour service</source>
-        <translation>மையக பிரிவு தேடல் சேவை செயல்படுத்தப்படாத போது இந்த உபகரணம் மற்ற உபகரணங்களால் தேடப்படாது மற்றும் தேடப்படாது விண்டோஸ் தொடங்க மென்மூ, -> கணினி மேலாண்மை -> சேவைகள் மற்றும் பயன்பாடுகள் -> சேவைகளை கிளிக் செய்யவும், Bonjour சேவையை செயல்படுத்தவும்</translation>
+        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned onRight click on Windows Start menu -&gt;Computer Management -&gt;Services and Applications -&gt;Services to enable Bonjour service</source>
+        <translation>மையக பிரிவு தேடல் சேவை செயல்படுத்தப்படாத போது இந்த உபகரணம் மற்ற உபகரணங்களால் தேடப்படாது மற்றும் தேடப்படாது விண்டோஸ் தொடங்க மென்மூ, -&gt; கணினி மேலாண்மை -&gt; சேவைகள் மற்றும் பயன்பாடுகள் -&gt; சேவைகளை கிளிக் செய்யவும், Bonjour சேவையை செயல்படுத்தவும்</translation>
     </message>
 </context>
 <context>
@@ -261,6 +262,7 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="158"/>
+        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="166"/>
         <source>the file save location is invalid</source>
         <translation>கோப்பை சேமிக்க முடியாத இடம்</translation>
     </message>
@@ -310,16 +312,19 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="285"/>
+        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="296"/>
         <source>Cancel</source>
         <translation>தவறு</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="286"/>
+        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="295"/>
         <source>Confirm</source>
         <translation>உறுதியளிக்க</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="287"/>
+        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="294"/>
         <source>Please select your operation</source>
         <translation>உங்கள் செயல்பாட்டை தேர்வு செய்யவும்</translation>
     </message>
@@ -353,6 +358,7 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="84"/>
+        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="126"/>
         <source>Settings</source>
         <translation>அமைப்புகள்</translation>
     </message>
@@ -389,13 +395,13 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="204"/>
-        <source>3. File Manager-Settings-File Drop-Allow the following users to drop files to me -"Everyone on the same LAN"</source>
-        <translation>3. கோப்பை மேலோங்கி-அமைப்புகள்-கோப்பு தரவு-கீழே கொண்டார்கள் கோப்புகளை எனக்கு தரவு செய்ய அனுமதிக்கவும் -"ஒரே LAN இல் உள்ள அனைவரும்"</translation>
+        <source>3. File Manager-Settings-File Drop-Allow the following users to drop files to me -&quot;Everyone on the same LAN&quot;</source>
+        <translation>3. கோப்பை மேலோங்கி-அமைப்புகள்-கோப்பு தரவு-கீழே கொண்டார்கள் கோப்புகளை எனக்கு தரவு செய்ய அனுமதிக்கவும் -&quot;ஒரே LAN இல் உள்ள அனைவரும்&quot;</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="206"/>
-        <source>3. Settings-Basic Settings-Discovery Mode-"Allow everyone in the same LAN"</source>
-        <translation>3. அமைப்புகள்-பிரிவுகள்-கண்டுபிடிப்பு திட்டம்-"ஒரே LAN இல் உள்ள அனைவரும் அனுமதிக்கவும்"</translation>
+        <source>3. Settings-Basic Settings-Discovery Mode-&quot;Allow everyone in the same LAN&quot;</source>
+        <translation>3. அமைப்புகள்-பிரிவுகள்-கண்டுபிடிப்பு திட்டம்-&quot;ஒரே LAN இல் உள்ள அனைவரும் அனுமதிக்கவும்&quot;</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="212"/>
@@ -414,8 +420,8 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="246"/>
-        <source>Go to download></source>
-        <translation>மேலோங்கி கொண்டார்கள்></translation>
+        <source>Go to download&gt;</source>
+        <translation>மேலோங்கி கொண்டார்கள்&gt;</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="250"/>
@@ -455,11 +461,13 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="95"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="212"/>
         <source>cancel</source>
         <translation>வெறுக்கவும்</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="96"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="157"/>
         <source>comfirm</source>
         <translation>உறுதிப்படுத்தவும்</translation>
     </message>
@@ -470,8 +478,8 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="210"/>
-        <source>Are you sure to disconnect and collaborate with '%1'?</source>
-        <translation>உங்கள் முன்னேற்றம் '%1' கோப்பை மேலோங்கி இணைக்க தொடர்பு ந断 மற்றும் பொருளை கோப்பை மேலோங்கி இணைக்க உறுதியாக உள்ளதா?</translation>
+        <source>Are you sure to disconnect and collaborate with &apos;%1&apos;?</source>
+        <translation>உங்கள் முன்னேற்றம் &apos;%1&apos; கோப்பை மேலோங்கி இணைக்க தொடர்பு ந断 மற்றும் பொருளை கோப்பை மேலோங்கி இணைக்க உறுதியாக உள்ளதா?</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="213"/>
@@ -535,11 +543,13 @@
     <name>cooperation_core::SettingDialogPrivate</name>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="47"/>
+        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="53"/>
         <source>Everyone in the same LAN</source>
         <translation>அனைத்து ஒரே LAN இலும் உள்ளவர்கள்</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="49"/>
+        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="55"/>
         <source>Not allow</source>
         <translation>அனுமதிக்க இல்லை</translation>
     </message>
@@ -570,8 +580,8 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="145"/>
-        <source>Other devices can discover and connect with you through the "Cooperation" app</source>
-        <translation>மற்ற கருவிகள் "Cooperation" ஆப்பின் மூலம் உங்களைக் கண்டுபிடித்து இணைக்கலாம்</translation>
+        <source>Other devices can discover and connect with you through the &quot;Cooperation&quot; app</source>
+        <translation>மற்ற கருவிகள் &quot;Cooperation&quot; ஆப்பின் மூலம் உங்களைக் கண்டுபிடித்து இணைக்கலாம்</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="195"/>
@@ -643,8 +653,12 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="263"/>
-        <source>Unable to collaborate to "%1"</source>
-        <translation> "%1" குறிப்பிட்ட பக்கத்துடன் ஒருங்கிணைக்க முடியவில்லை</translation>
+        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="392"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="448"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="458"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="511"/>
+        <source>Unable to collaborate to &quot;%1&quot;</source>
+        <translation> &quot;%1&quot; குறிப்பிட்ட பக்கத்துடன் ஒருங்கிணைக்க முடியவில்லை</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="265"/>
@@ -653,18 +667,19 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="280"/>
-        <source>Requesting collaborate to "%1"</source>
-        <translation> "%1" குறிப்பிட்ட பக்கத்துடன் ஒருங்கிணைக்க கோரிக்கை செய்கிறீர்கള்</translation>
+        <source>Requesting collaborate to &quot;%1&quot;</source>
+        <translation> &quot;%1&quot; குறிப்பிட்ட பக்கத்துடன் ஒருங்கிணைக்க கோரிக்கை செய்கிறீர்கള்</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="307"/>
-        <source>Coordination with "%1" has ended</source>
-        <translation> "%1" குறிப்பிட்ட பக்கத்துடன் ஒருங்கிணைப்பு முடிவுக்கு வந்துள்ளது</translation>
+        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="483"/>
+        <source>Coordination with &quot;%1&quot; has ended</source>
+        <translation> &quot;%1&quot; குறிப்பிட்ட பக்கத்துடன் ஒருங்கிணைப்பு முடிவுக்கு வந்துள்ளது</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="353"/>
-        <source>A cross-end collaboration request was received from "%1"</source>
-        <translation> "%1" இருந்து ஒருங்கிணைப்பு கோரிக்கை பெற்றுள்ளது</translation>
+        <source>A cross-end collaboration request was received from &quot;%1&quot;</source>
+        <translation> &quot;%1&quot; இருந்து ஒருங்கிணைப்பு கோரிக்கை பெற்றுள்ளது</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="354"/>
@@ -683,8 +698,8 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="393"/>
-        <source>Connect to "%1" failed</source>
-        <translation> "%1" குறிப்பிட்ட பக்கத்துடன் இணைப்பு வெற்றியில்லை</translation>
+        <source>Connect to &quot;%1&quot; failed</source>
+        <translation> &quot;%1&quot; குறிப்பிட்ட பக்கத்துடன் இணைப்பு வெற்றியில்லை</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="418"/>
@@ -698,23 +713,23 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="441"/>
-        <source>Connection successful, coordinating with  "%1"</source>
-        <translation>கட்டுப்பாடு வலிமை, "%1" குறித்து ஒப்பநாடு செய்யப்பட்டுள்ளது</translation>
+        <source>Connection successful, coordinating with  &quot;%1&quot;</source>
+        <translation>கட்டுப்பாடு வலிமை, &quot;%1&quot; குறித்து ஒப்பநாடு செய்யப்பட்டுள்ளது</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="449"/>
-        <source>"%1" has rejected your request for collaboration</source>
-        <translation>"%1" உங்கள் தொடர்பு கொள்ள கோரிக்கையை நிராகரித்துள்ளது</translation>
+        <source>&quot;%1&quot; has rejected your request for collaboration</source>
+        <translation>&quot;%1&quot; உங்கள் தொடர்பு கொள்ள கோரிக்கையை நிராகரித்துள்ளது</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="459"/>
-        <source>"%1" is connecting with other devices</source>
-        <translation>"%1" வேறு உபகரணங்களுடன் இணைக்கப்படுகிறது</translation>
+        <source>&quot;%1&quot; is connecting with other devices</source>
+        <translation>&quot;%1&quot; வேறு உபகரணங்களுடன் இணைக்கப்படுகிறது</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="503"/>
-        <source>The connection request sent to you by "%1" was interrupted due to a timeout</source>
-        <translation>"%1" இன் கட்டுப்பாடு கோரிக்கை நீங்கள் அனுப்பியது வேதியில் காலங்காலம் காரணமாக துண்டிக்கப்பட்டுள்ளது</translation>
+        <source>The connection request sent to you by &quot;%1&quot; was interrupted due to a timeout</source>
+        <translation>&quot;%1&quot; இன் கட்டுப்பாடு கோரிக்கை நீங்கள் அனுப்பியது வேதியில் காலங்காலம் காரணமாக துண்டிக்கப்பட்டுள்ளது</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="513"/>
@@ -753,42 +768,47 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="563"/>
-        <source>Please check the network "%1"</source>
-        <translation>மீண்டும் "%1" நெட்வேர்க்கை சரிபார்க்கவும்</translation>
+        <source>Please check the network &quot;%1&quot;</source>
+        <translation>மீண்டும் &quot;%1&quot; நெட்வேர்க்கை சரிபார்க்கவும்</translation>
     </message>
 </context>
 <context>
     <name>cooperation_core::ShareHelperPrivate</name>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="103"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="109"/>
         <source>Cooperation</source>
         <translation>தொடர்பு</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="200"/>
-        <source>Connection successful, coordinating with "%1"</source>
-        <translation>இணைப்பு வலிமை, "%1" குறித்து ஒப்பநாடு செய்யப்பட்டுள்ளது</translation>
+        <source>Connection successful, coordinating with &quot;%1&quot;</source>
+        <translation>இணைப்பு வலிமை, &quot;%1&quot; குறித்து ஒப்பநாடு செய்யப்பட்டுள்ளது</translation>
     </message>
 </context>
 <context>
     <name>cooperation_core::TransferHelper</name>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="433"/>
-        <source>Connect to "%1" failed</source>
-        <translation>"%1" இணைப்பு வேதியில்</translation>
+        <source>Connect to &quot;%1&quot; failed</source>
+        <translation>&quot;%1&quot; இணைப்பு வேதியில்</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="458"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="609"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="683"/>
         <source>File read/write exception</source>
         <translation>பொருட்களை படிக்க/எழுத வேதியில்</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="579"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="630"/>
         <source>The other party has canceled the file transfer</source>
         <translation>மற்றப்பகுதி பொருட்களை அனுப்ப கோரிக்கையை ரத்து செய்துள்ளது</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="478"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="626"/>
         <source>File sent successfully</source>
         <translation>பொருட்கள் வலிமை அனுப்பப்பட்டுள்ளது</translation>
     </message>
@@ -819,13 +839,13 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
-        <source>Sending files to "%1"</source>
-        <translation>பொருட்களை "%1" க்கு அனுப்புகின்றன</translation>
+        <source>Sending files to &quot;%1&quot;</source>
+        <translation>பொருட்களை &quot;%1&quot; க்கு அனுப்புகின்றன</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
-        <source>Receiving files from "%1"</source>
-        <translation>பொருட்களை "%1" இருந்து பெறுகின்றன</translation>
+        <source>Receiving files from &quot;%1&quot;</source>
+        <translation>பொருட்களை &quot;%1&quot; இருந்து பெறுகின்றன</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="399"/>
@@ -844,8 +864,8 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="394"/>
-        <source>"%1" send some files to you</source>
-        <translation>"%1" உங்களுக்கு சில கோப்புகளை அனுப்புகிறது</translation>
+        <source>&quot;%1&quot; send some files to you</source>
+        <translation>&quot;%1&quot; உங்களுக்கு சில கோப்புகளை அனுப்புகிறது</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="313"/>
@@ -859,14 +879,18 @@
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="452"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="605"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="680"/>
         <source>Insufficient storage space, file delivery failed this time. Please clean up disk space and try again!</source>
-        <translation>>-
+        <translation>&gt;-
  சேமிப்பு இடம் பெரிதாக இல்லை, இந்த முறை கோպ்பு கொண்டாட்டம் வெற்றியின்றி முடிந்தது. தயவு செய்து கோப்புகளை நீக்கி, மீண்டும் முயற்சி செய்யவும்!</translation>
     </message>
     <message>
         <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="455"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="607"/>
+        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="677"/>
         <source>Network not connected, file delivery failed this time. Please connect to the network and try again!</source>
-        <translation>>-
+        <translation>&gt;-
  நெட்வேர் இணைக்கப்படவில்லை, இந்த முறை கோப்பு கொண்டாட்டம் வெற்றியின்றி முடிந்தது. தயவு செய்து நெட்வேர் இணைக்கவும் மீண்டும் முயற்சி செய்யவும்!</translation>
     </message>
     <message>
@@ -892,6 +916,7 @@
     <name>cooperation_core::VncViewer</name>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="211"/>
+        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="213"/>
         <source>Disconnected</source>
         <translation>தொடர்பு இல்லை</translation>
     </message>
@@ -913,6 +938,7 @@
     <name>cooperation_core::WorkspaceWidgetPrivate</name>
     <message>
         <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="52"/>
+        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="53"/>
         <source>Please enter the device ip/name of the collaborator</source>
         <translation>தொடர்பு கொண்டவரின் உபகரணம் IP/பெயரை உள்ளீடு செய்யவும்</translation>
     </message>
@@ -984,4 +1010,4 @@
         <translation>கோப்பு சேமிப்பு இடம்</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
